@@ -10,6 +10,8 @@ from .dbs import DatabasesAPI
 from .tokens import TokensAPI
 from .images import ImagesAPI
 from .dedics import DedicsAPI
+from .k8s import KubernetesAPI
+from .domains import DomainsAPI
 from .account import AccountAPI
 from .ssh_keys import SSHKeysAPI
 from .balancers import BalancersAPI
@@ -46,6 +48,8 @@ class Timeweb:
         dbs (DatabasesAPI): API для работы с базами данных.
         servers (Servers): API для работы с серверами.
         balancers (BalancersAPI): API для работы с балансировщиками.
+        k8s (KubernetesAPI): API для работы с Kubernetes.
+        domains (DomainsAPI): API для работы с доменами.
     '''
 
     def __init__(self, token: str, client: Client | None = None):
@@ -64,3 +68,5 @@ class Timeweb:
         self.dbs = DatabasesAPI(token, client)
         self.servers = Servers(token, client)
         self.balancers = BalancersAPI(token, client)
+        self.k8s = KubernetesAPI(token, client)
+        self.domains = DomainsAPI(token, client)
